diff --git a/CHANGELOG.md b/CHANGELOG.md
--- a/CHANGELOG.md
+++ b/CHANGELOG.md
@@ -1,5 +1,9 @@
 # Change Log
 
+## 0.17.0.3 - 2022-04-18
+
+* Fix typos and terminology ([#81](https://github.com/haskell/ghc-events/pull/81), [#82](https://github.com/haskell/ghc-events/pull/82))
+
 ## 0.17.0.2 - 2022-02-14
 
 * Clarify usage of IntMap EventType in ppEvent ([#80](https://github.com/haskell/ghc-events/pull/80))
diff --git a/GhcEvents.hs b/GhcEvents.hs
--- a/GhcEvents.hs
+++ b/GhcEvents.hs
@@ -214,11 +214,11 @@
 
 showValidate :: (s -> String) -> (i -> String) -> Either (s, i) s -> String
 showValidate showState showInput (Left (state, input)) =
-  "Invalid eventlog:"
+  "Invalid event log:"
   ++ "\nState:\n" ++ showState state
   ++ "\nInput:\n" ++ showInput input
 showValidate showState _ (Right state) =
-  "Valid eventlog: " ++ showState state
+  "Valid event log: " ++ showState state
 
 showProcess :: (Show e, Show a) => Process e a -> String
 showProcess process =
diff --git a/ghc-events.cabal b/ghc-events.cabal
--- a/ghc-events.cabal
+++ b/ghc-events.cabal
@@ -1,6 +1,6 @@
 cabal-version:    2.4
 name:             ghc-events
-version:          0.17.0.2
+version:          0.17.0.3
 synopsis:         Library and tool for parsing .eventlog files from GHC
 description:      Parses .eventlog files emitted by GHC 6.12.1 and later.
                   Includes the ghc-events tool permitting, in particular,
diff --git a/src/GHC/RTS/EventParserUtils.hs b/src/GHC/RTS/EventParserUtils.hs
--- a/src/GHC/RTS/EventParserUtils.hs
+++ b/src/GHC/RTS/EventParserUtils.hs
@@ -65,7 +65,7 @@
 --
 
 --
--- | Event parser data. Parsers are either fixed or vairable size.
+-- | Event parser data. Parsers are either fixed or variable size.
 --
 data EventParser a
     = FixedSizeParser {
@@ -114,7 +114,7 @@
 --
 -- Summary:
 --   if size is smaller that we expect:
---     parse the earier version, or ignore the event
+--     parse the earlier version, or ignore the event
 --   if size is just right:
 --     parse it
 --   if size is too big:
diff --git a/src/GHC/RTS/Events.hs b/src/GHC/RTS/Events.hs
--- a/src/GHC/RTS/Events.hs
+++ b/src/GHC/RTS/Events.hs
@@ -105,15 +105,15 @@
 import Data.Monoid ((<>))
 #endif
 
--- | Read an entire eventlog file. It returns an error message if it
--- encouters an error while decoding.
+-- | Read an entire event log file. It returns an error message if it
+-- encounters an error while decoding.
 --
 -- Note that it doesn't fail if it consumes all input in the middle of decoding
 -- of an event.
 readEventLogFromFile :: FilePath -> IO (Either String EventLog)
 readEventLogFromFile path = fmap fst . readEventLog <$> BL.readFile path
 
--- | Read an eventlog file and pretty print it to stdout
+-- | Read an event log file and pretty print it to stdout
 printEventsIncremental
   :: Bool -- ^ Follow the file or not
   -> FilePath
@@ -121,7 +121,7 @@
 printEventsIncremental follow path =
   withFile path ReadMode (hPrintEventsIncremental follow)
 
--- | Read an eventlog from the Handle and pretty print it to stdout
+-- | Read an event log from the Handle and pretty print it to stdout
 hPrintEventsIncremental
   :: Bool -- ^ Follow the handle or not
   -> Handle
@@ -178,7 +178,7 @@
   (x:xs) -> capSplitEvents' xs (IM.insertWith (++) (getIntCap x) [x] imap)
   []     -> imap
 
--- Adds a block marker to the beginnng of a list of events, annotated with
+-- Adds a block marker to the beginning of a list of events, annotated with
 -- its capability. All events are expected to belong to the same cap.
 addBlockMarker :: Int -> [Event] -> [Event]
 addBlockMarker cap evts =
diff --git a/src/GHC/RTS/Events/Analysis.hs b/src/GHC/RTS/Events/Analysis.hs
--- a/src/GHC/RTS/Events/Analysis.hs
+++ b/src/GHC/RTS/Events/Analysis.hs
@@ -66,7 +66,7 @@
 
 --------------------------------------------------------------------------------
 -- A Process is a list of successful values, followed by an error if one
--- occured. This captures the idea that a computation may produce a list of
+-- occurred. This captures the idea that a computation may produce a list of
 -- elements before possibly failing. This gives us an incremental interface
 -- to data processed from machine transitions.
 data Process e a
diff --git a/src/GHC/RTS/Events/Binary.hs b/src/GHC/RTS/Events/Binary.hs
--- a/src/GHC/RTS/Events/Binary.hs
+++ b/src/GHC/RTS/Events/Binary.hs
@@ -947,7 +947,7 @@
   , simpleEvent EVENT_TICKY_BEGIN_SAMPLE TickyBeginSample
   ]
 
--- | String byte length in the eventlog format. It includes
+-- | String byte length in the event log format. It includes
 -- 1 byte for NUL.
 textByteLen :: T.Text -> Int
 textByteLen = (+1) . B.length . TE.encodeUtf8
@@ -1133,7 +1133,7 @@
 
 -- here we assume that ThreadStopStatus fromEnum matches the definitions in
 -- EventLogFormat.h
--- The standard encoding is used here, which is wrong for eventlogs
+-- The standard encoding is used here, which is wrong for event logs
 -- produced by GHC-7.8.2 ([Stop status in GHC-7.8.2] in EventTypes.hs
 putEventSpec (StopThread t s) = do
     putE t
diff --git a/src/GHC/RTS/Events/Incremental.hs b/src/GHC/RTS/Events/Incremental.hs
--- a/src/GHC/RTS/Events/Incremental.hs
+++ b/src/GHC/RTS/Events/Incremental.hs
@@ -143,7 +143,7 @@
       Done {} -> []
       Error _ err -> [Left err]
 
--- | Read an entire eventlog from a lazy bytestring. It returns an error message if it
+-- | Read an entire event log from a lazy bytestring. It returns an error message if it
 -- encounters an error while decoding.
 --
 -- Note that it doesn't fail if it consumes all input in the middle of decoding
diff --git a/src/GHC/RTS/Events/Merge.hs b/src/GHC/RTS/Events/Merge.hs
--- a/src/GHC/RTS/Events/Merge.hs
+++ b/src/GHC/RTS/Events/Merge.hs
@@ -9,9 +9,9 @@
 import Prelude
 
 -- TODO: add a merge mode where the events are synchronized using
--- the wall clock time event at the start of both eventlogs (for newer GHCs).
+-- the wall clock time event at the start of both event logs (for newer GHCs).
 -- Such merge is not associative so we either need to take many arguments
--- or cope with eventlogs with many wall clock time events (assume they
+-- or cope with event logs with many wall clock time events (assume they
 -- are products of previous merges). To decide.
 
 {-
@@ -31,7 +31,7 @@
       m1 = headerMap $ eventTypes h1
       m2 = headerMap $ eventTypes h2
       combine et1 et2 | et1 == et2 = et1
-      combine _ _ = error "can't merge eventlogs with inconsistent headers"
+      combine _ _ = error "can't merge event logs with inconsistent headers"
       m = M.unionWith combine m1 m2
       h = Header $ M.elems m
   in h == h `seq`  -- Detect inconsistency ASAP.
diff --git a/test/Roundtrip.hs b/test/Roundtrip.hs
--- a/test/Roundtrip.hs
+++ b/test/Roundtrip.hs
@@ -5,7 +5,7 @@
 import GHC.RTS.Events.Incremental
 import Utils (files)
 
--- | Check that an eventlog round-trips through encoding/decoding.
+-- | Check that an event log round-trips through encoding/decoding.
 checkRoundtrip :: FilePath -> IO Bool
 checkRoundtrip logFile = do
   putStrLn logFile

diff --git a/src/GHC/RTS/EventTypes.hs b/src/GHC/RTS/EventTypes.hs
--- a/src/GHC/RTS/EventTypes.hs
+++ b/src/GHC/RTS/EventTypes.hs
@@ -335,7 +335,7 @@
                               receiverInport :: {-# UNPACK #-} !PortId
                             }
 
-  -- These events have been added for Mercury's benifit but are generally
+  -- These events have been added for Mercury's benefit but are generally
   -- useful.
   | InternString       { str :: String, sId :: {-# UNPACK #-}!StringId }
 
@@ -488,7 +488,7 @@
 
 The parsers in Events.hs have to be adapted accordingly, providing
 special ghc-7.8.2 parsers for the thread-stop event if GHC-7.8.2
-produced the eventlog.
+produced the event log.
 The EVENT_USER_MARKER was not present in GHC-7.6.3, and a new event
 EVENT_HACK_BUG_T9003 was added in GHC-7.8.3, so we take presence of
 USER_MARKER and absence of HACK_BUG_T9003 as an indication that
@@ -542,7 +542,7 @@
  16 ->  BlockedOnMsgThrowTo
  17 ->  ThreadMigrating
  18 ->  BlockedOnMsgGlobalise
- 19 ->  NoStatus -- yeuch... this one does not actually exist in GHC eventlogs
+ 19 ->  NoStatus -- yeuch... this one does not actually exist in GHC event logs
  20 ->  BlockedOnMVarRead -- since GHC-7.8.3
  _  ->  error "mkStat"
 